@@ -1,4 +1,3 @@
-import json
 import logging
 from copy import deepcopy
 from dataclasses import dataclass
@@ -15,31 +14,57 @@ class CorganizeClient:
     apikey: str
 
     @property
-    def _headers(self):
-        return {
-            "apikey": self.apikey
-        }
+    def _default_headers(self):
+        return {"apikey": self.apikey}
 
     def _compose_url(self, resource):
         return "/".join([s.strip("/") for s in (self.host, resource)])
 
-    def update(self, file):
+    def get_recent_files(self, limit):
         url = self._compose_url("/files")
-        r = requests.patch(url, json=file, headers=self._headers)
-        r.raise_for_status()
+        return self._get_paginated_files(url, limit=limit)
+
+    def get_active_files(self, limit):
+        url = self._compose_url("/files/active")
+        return self._get_paginated_files(url, limit=limit)
+
+    def get_incomplete_files(self, limit):
+        url = self._compose_url("/files/incomplete")
+        return self._get_paginated_files(url, limit=limit)
+
+    def create_files(self, files: List[dict]):
+        assert isinstance(files, list)
 
-    def create(self, files: List[dict]):
         url = self._compose_url("/files/bulk")
-        r = requests.post(url, json=files, headers=self._headers)
-        r.raise_for_status()
+        r = requests.post(url, json=files, headers=self._default_headers)
+
+        if not r.ok:
+            raise RuntimeError(r.text)
+
         return r.json()
 
+    def update_file(self, file):
+        assert isinstance(file, dict)
+
+        url = self._compose_url("/files")
+        r = requests.patch(url, json=file, headers=self._default_headers)
+
+        if not r.ok:
+            raise RuntimeError(r.text)
+
+    def delete_file(self, fileid: str):
+        assert isinstance(fileid, str)
+
+        url = self._compose_url("/files")
+        r = requests.delete(url, json={"fileid": fileid}, headers=self._default_headers)
+        r.raise_for_status()
+
     def _get_paginated_files(self, url: str, headers: dict = None, limit: int = 1000):
         return_files = list()
 
         if not headers:
-            LOGGER.debug("headers not provided. Using the default dictionary...")
-            headers = self._headers
+            LOGGER.debug("headers not provided. Using the default headers...")
+            headers = self._default_headers
 
         headers_deepcopy = deepcopy(headers)
 
@@ -73,17 +98,3 @@ class CorganizeClient:
             return return_files[:limit]
 
         return return_files
-
-    def get_incomplete_files(self, limit):
-        # Get the list of incomplete files whose 'ispublic' field does not exist or is True.
-        url = self._compose_url("/files/incomplete")
-        return [f for f in self._get_paginated_files(url, limit=limit) if f.get("ispublic", True)]
-
-    def get_active_files(self, limit):
-        url = self._compose_url("/files/active")
-        return self._get_paginated_files(url, limit=limit)
-
-    def delete(self, fileid: str):
-        url = self._compose_url("/files")
-        r = requests.delete(url, data=json.dumps({"fileid": fileid}), headers=self._headers)
-        r.raise_for_status()
